DebuggerHealth class

Annotations

Constructors

DebuggerHealth({required List<String> messages, required bool isHealthy})
const
DebuggerHealth.fromSnapshot(EcsDebuggerSnapshot snapshot, {PerformanceDebuggerSnapshot? performance, MemoryDebuggerSnapshot? memory})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
hasWarnings bool
no setter
isHealthy bool
final
messages List<String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited